@@ -275,7 +275,7 @@ class JobStatus(proto.Message):
 
         Values:
             STATE_UNSPECIFIED (0):
-
+                No description available.
             QUEUED (1):
                 Job is admitted (validated and persisted) and
                 waiting for resources.
@@ -316,6 +316,8 @@ class JobStatus(proto.Message):
             task_pack (int):
                 The max number of tasks can be assigned to
                 this instance type.
+            boot_disk (google.cloud.batch_v1alpha.types.AllocationPolicy.Disk):
+                The VM boot disk.
         """
 
         machine_type: str = proto.Field(
@@ -331,6 +333,11 @@ class JobStatus(proto.Message):
             proto.INT64,
             number=3,
         )
+        boot_disk: "AllocationPolicy.Disk" = proto.Field(
+            proto.MESSAGE,
+            number=4,
+            message="AllocationPolicy.Disk",
+        )
 
     class TaskGroupStatus(proto.Message):
         r"""Aggregated task status for a TaskGroup.
@@ -554,8 +561,17 @@ class AllocationPolicy(proto.Message):
 
         Attributes:
             image (str):
-                Name of a public or custom image used as the
-                data source.
+                Name of a public or custom image used as the data source.
+                For example, the following are all valid URLs: (1) Specify
+                the image by its family name:
+                projects/{project}/global/images/family/{image_family} (2)
+                Specify the image version:
+                projects/{project}/global/images/{image_version} You can
+                also use Batch customized image in short names. The
+                following image values are supported for a boot disk:
+                "batch-debian": use Batch Debian images. "batch-centos": use
+                Batch CentOS images. "batch-cos": use Batch
+                Container-Optimized images.
 
                 This field is a member of `oneof`_ ``data_source``.
             snapshot (str):
@@ -563,14 +579,20 @@ class AllocationPolicy(proto.Message):
 
                 This field is a member of `oneof`_ ``data_source``.
             type_ (str):
-                Disk type as shown in ``gcloud compute disk-types list`` For
-                example, "pd-ssd", "pd-standard", "pd-balanced",
-                "local-ssd".
+                Disk type as shown in ``gcloud compute disk-types list``.
+                For example, local SSD uses type "local-ssd". Persistent
+                disks and boot disks use "pd-balanced", "pd-extreme",
+                "pd-ssd" or "pd-standard".
             size_gb (int):
-                Disk size in GB. This field is ignored if ``data_source`` is
-                ``disk`` or ``image``. If ``type`` is ``local-ssd``, size_gb
-                should be a multiple of 375GB, otherwise, the final size
-                will be the next greater multiple of 375 GB.
+                Disk size in GB. For persistent disk, this field is ignored
+                if ``data_source`` is ``image`` or ``snapshot``. For local
+                SSD, size_gb should be a multiple of 375GB, otherwise, the
+                final size will be the next greater multiple of 375 GB. For
+                boot disk, Batch will calculate the boot disk size based on
+                source image and task requirements if you do not speicify
+                the size. If both this field and the boot_disk_mib field in
+                task spec's compute_resource are defined, Batch will only
+                honor this field.
             disk_interface (str):
                 Local SSDs are available through both "SCSI"
                 and "NVMe" interfaces. If not indicated, "NVMe"
